require 'optparse'
require 'rack'
require 'flunkey'

module Flunkey
  class Application
    attr_accessor :options

    def run(args = ARGV)
      @options = parse(args)
      run_server
    end

    def default_options
      root = File.expand_path('../../', File.dirname(__FILE__))
      {
        root: root,
        port: 8080,
        address: '127.0.0.1',
        paths: [root]
      }
    end

    def parse(args)
      optparse = OptionParser.new do|opts|
        opts.on_tail("-h", "--help", "Show this message") do
          puts opts
          exit
        end

        opts.on_tail("--version", "Show version") do
          puts Flunkey::VERSION
          exit
        end
      end
      optparse.parse(args)
      options.merge default_options
    end

    def self.run(args = ARGV)
      new.run(args)
    end

    def initialize
      self.options = {}
    end

    def run_server
      Flunkey::Server.run! self.options
    end

  end
end
