module Flunkey
  module Helpers

    # Byte per second
    DOWNLOAD_SPEEDS = {
      'Modem'=>7000,
      'EDGE'=>24500,
      'DSL Light'=>96000,
      'DSL 3000'=>375000,
      'DSL 16000'=>2000000
    }

    def config
      settings
    end

    def title
      return @title if @title
      if @path && @root
        return (@root.basename + @path.relative_path_from(@root)).to_s
      end
      "Flunkey #{Flunkey::VERSION}"
    end

    def icon_for(path)
      icon = case
        when path.directory? then "fa-folder"
        when path.bundle? then "fa-file-o"
        else "fa-file-o"
      end
      "<i class='fa #{icon}'></i>"
    end

    def to_url(root, path)
      "/#{root.basename + path.relative_path_from(root)}"
    end

    def breadcrumbs(root, path)
      b = [root.dup]
      return b if root==path
      path.relative_path_from(root).descend{|p| b << root + p }
      b
    end

    def download_estimates(size)
      result = []
      DOWNLOAD_SPEEDS.each do |name, speed|
        result << [name, (size/speed).round(1)]
      end
      result.sort{|a,b| b[1]<=>a[1]}
    end

    def localize(date)
      date.strftime('%d.%m.%Y %H:%M')
    end

    alias_method :l, :localize

    def debug(obj)
      "<pre>#{Rack::Utils.escape_html obj.inspect}</pre>"
    end

  end
end
