module Flunkey
  module PathnameExtensions

    BUNDLE_TEST = /com\.apple\.bundle/
    EXCLUDE_PATTERNS = [
      /^\..*/
    ]

    def exclude_patterns
      @exclude_patterns || EXCLUDE_PATTERNS
    end

    def browsable?
      return false unless exist? && readable?
      return false if bundle?
      return true if directory?
      false
    end

    def downloadable?
      return false unless exist? && readable?
      return false if directory?
      true
    end

    def compressable?
      return false unless exist? && readable?
      true
    end

    def bundle?
      return false unless directory?
      return true if `/usr/bin/mdls -name kMDItemContentTypeTree #{to_s}` =~ BUNDLE_TEST
      false
    end

    def excluded?
      return true if exclude_patterns.any?{|pat| pat.match self.basename.to_s}
    end

    def metadata(*keys)
      @metadata ||= Flunkey::Metadata.parse `/usr/bin/mdls #{to_s}`
    end

    def is_parent_of?(path)
      return false if path.nil?
      return false unless self.absolute? && path.absolute?
      return false if self == path
      p = path.to_s.split('/')
      self.to_s.split('/').each_with_index { |elem, idx|
        return false unless elem == p[idx]
      }
      true
    end

    def filtered_children
      children.delete_if(&:excluded?)
    end

  end
end
