require 'sinatra/base'
require 'sinatra/partial'
require 'sinatra/reloader'
require 'active_support/number_helper'

module Flunkey
  class Server < Sinatra::Base

    include Functions

    def initialize(app = nil)
      super(app)
      settings.paths = settings.paths.map{|p| Pathname.new(p) }.find_all{|p| p.browsable?}
    end

    configure do
      register Sinatra::Partial
      set :partial_template_engine, :erb
      enable :partial_underscores
    end

    configure :development do
      register Sinatra::Reloader
    end

    helpers Flunkey::Helpers, ActiveSupport::NumberHelper

    get '/_search' do
      @title = "Search results"
      @query = params[:query]
      @results = search(@query)
      erb :search
    end

    get '/*/info' do
      @root, @path = recognize params[:splat].first
      halt(404, erb(:not_found)) unless @root
      erb :info
    end

    get '/*/ql' do
      @root, @path = recognize params[:splat].first
      halt(404, erb(:not_found)) unless @root
      erb :info
    end

    get '/*' do
      path_info = params[:splat].first
      pass if path_info.blank?
      @root, @path = recognize path_info
      halt(404, erb(:not_found)) unless @root
      if @path.browsable?
        return erb :path
      end

      send_file @path, disposition: :attachment
    end

    get '/' do
      @paths = settings.paths
      erb :index
    end

  end
end
